clojure-commons.json


body->jsonclj

(body->json body)
(body->json body keywordize?)

Takes in input from a post body and slurps/parses it.

Takes in input from a post body and slurps/parses it.
sourceraw docstring

json-mime-typeclj

source

string->jsonclj

(string->json s)
(string->json s keywordize?)

Parses a JSON string.

Parses a JSON string.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries