(find-properties-file prop-name)Searches the classpath for the named properties file.
Searches the classpath for the named properties file.
(load-properties-configuration file-name)Loads a configuration from a file using Apache's Commons Configuration library.
Loads a configuration from a file using Apache's Commons Configuration library.
(read-properties file-path)Reads in properties from a file and instantiates a loaded Properties object. Adapted from code in the clojure.contrib.properties.
Reads in properties from a file and instantiates a loaded Properties object. Adapted from code in the clojure.contrib.properties.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |